@@ -6,12 +6,14 @@ use warnings;
 use Dancer::Plugin;
 use MongoDB 0.38;
 
+our $VERSION = 0.03;
+
 my $settings = plugin_setting;
 my $conn;
 
 ## return a connected MongoDB object
 register mongo => sub {
-    
+
     $conn ? $conn : $conn = MongoDB::Connection->new( _slurp_settings() ) ;
 
     return $conn;
@@ -21,12 +23,12 @@ register_plugin;
 
 sub _slurp_settings {
     
-    my $args;
+    my $args = {};
     for (qw/ host port username password w wtimeout auto_reconnect auto_connect
-	timeout db_name query_timeout find_master/) {
-	if (exists $settings->{$_}) {
-	    $args->{$_} = $settings->{$_};
-	}
+        timeout db_name query_timeout find_master/) {
+        if (exists $settings->{$_}) {
+            $args->{$_} = $settings->{$_};
+        }
     }
 
     return $args;
@@ -44,7 +46,7 @@ Dancer::Plugin::Mongo - MongoDB plugin for the Dancer micro framework
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -52,7 +54,7 @@ version 0.02
     use Dancer::Plugin::Mongo;
 
     get '/widget/view/:id' => sub {
-	my $widget = mongo->database->table->find_one({ id => params->{id} });
+        my $widget = mongo->database->collection->find_one({ id => params->{id} });
     }
 
 =head1 DESCRIPTION
@@ -61,30 +63,30 @@ Dancer::Plugin::Mongo provides a wrapper around L<MongoDB>. Add the appropriate
 configuraton options to your config.yml and then you can access a MongoDB database
 using the 'mongo' keyword.
 
-To query the database, use the standard MongoDB syntax, described in 
+To query the database, use the standard MongoDB syntax, described in
 L<MongoDB::Collection>.
 
 =head1 CONFIGURATON
 
 Connection details will be taken from your Dancer application config file, and
-should be specified as, for example:
+should be specified as follows:
 
     plugins:
-	Mongo:
-	    host:
-	    port:
-	    username:
-	    password:
-	    w:
-	    wtimeout:
-	    auto_reconnect:
-	    auto_connect:
-	    timeout:
-	    db_name:
-	    query_timeout:
-	    find_master:
+        Mongo:
+            host:
+            port:
+            username:
+            password:
+            w:
+            wtimeout:
+            auto_reconnect:
+            auto_connect:
+            timeout:
+            db_name:
+            query_timeout:
+            find_master:
 
-All these configuration values are optional, full details are in the 
+All these configuration values are optional, full details are in the
 L<MongoDB::Connection> documentation.
 
 =head1 AUTHOR
